pub enum SteadyStateError {
BackupDisabled,
Connection,
Lagged,
}Available on crate feature
e2e-encryption only.Expand description
Error describing the ways that waiting for the backup upload to settle down can fail.
Variants
BackupDisabled
The currently active backup got either deleted or a new one was created.
No further room keys will be uploaded to the currently active backup.
Connection
Uploading the room keys to the homeserver failed due to a network error.
Uploading will be retried again at a later point in time, or immediately if you wait for the steady state again.
Lagged
We missed some updates to the UploadState from the upload task.
This error doesn’t imply that there was an error with the uploading of
room keys, it just means that we didn’t receive all the transitions in
the UploadState. You might want to retry waiting for the steady
state.